# Hive

<p align="center">
<img src="https://raw.githubusercontent.com/SimoneBendazzoli93/Hive/main/images/MAI_A_logo.png" width="50%" alt='Hive'>
</p>

[![Documentation Status](https://readthedocs.org/projects/hive-maia/badge/?version=latest)](https://hive-maia.readthedocs.io/en/latest/?badge=latest)
![Version](https://img.shields.io/badge/Hive-v1.1-blue)
[![License](https://img.shields.io/badge/license-GPL%203.0-green.svg)](https://opensource.org/licenses/GPL-3.0)
![Python](https://img.shields.io/badge/python-3.8+-orange)
![CUDA](https://img.shields.io/badge/CUDA-10.1%2F10.2%2F11.0-green)

## What is Hive?

Hive is a Python package to support Deep Learning data preparation, pre-processing. training, result visualization and
model deployment across different frameworks ([nnUNet](https://github.com/MIC-DKFZ/nnUNet)
, [nnDetection](https://github.com/MIC-DKFZ/nnDetection), [MONAI](https://monai.io/) ).